==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d7/daa/viewport__type_8h.js <==
var viewport__type_8h =
[
    [ "ViewPort", "d0/d83/structViewPort.html", "d0/d83/structViewPort" ],
    [ "ViewportSign", "dc/d5e/structViewportSign.html", "dc/d5e/structViewportSign" ],
    [ "ViewportDragDropSelectionProcess", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30", [
      [ "DDSP_DEMOLISH_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a85654f9645b8a2c365a504b61f21f16a", null ],
      [ "DDSP_RAISE_AND_LEVEL_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab6dd9eb95212827a1b570f10807d1026", null ],
      [ "DDSP_LOWER_AND_LEVEL_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a7096ba7607c7470a607660fb0e7bb217", null ],
      [ "DDSP_LEVEL_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab96b982939642251738df6d3c90a5f9e", null ],
      [ "DDSP_CREATE_DESERT", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a381d6451157c023f4fc9caf91724953f", null ],
      [ "DDSP_CREATE_ROCKS", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab1eb3e76148b1fb677c73bedd4cb3b79", null ],
      [ "DDSP_CREATE_WATER", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ac76d074d64e592506e9dd130b5a85a61", null ],
      [ "DDSP_CREATE_RIVER", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30adabd68f7dd962e9c9ea63a76eb9f8d24", null ],
      [ "DDSP_PLANT_TREES", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30acde8021d08a024a7b35d9067eb86c786", null ],
      [ "DDSP_BUILD_BRIDGE", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30af7a2f4c3b2084bdca11e0f0b44839406", null ],
      [ "DDSP_PLACE_RAIL", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30afdc07064cb21e25f2d8ce1f4101ec4fb", null ],
      [ "DDSP_BUILD_SIGNALS", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a895a704df13e062c23a2836d689257c2", null ],
      [ "DDSP_BUILD_STATION", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30abefc13bb25bea86d7bc45b328443508e", null ],
      [ "DDSP_REMOVE_STATION", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a8f7a7841a90238e9dad2b7570cc3eb3e", null ],
      [ "DDSP_CONVERT_RAIL", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a825f39718462a1f2220ce327bf490569", null ],
      [ "DDSP_PLACE_ROAD_X_DIR", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30aec49bff51948889c36e85dcba8a78597", null ],
      [ "DDSP_PLACE_ROAD_Y_DIR", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a263cf270b24732d2a5c06c32a8dfa824", null ],
      [ "DDSP_PLACE_AUTOROAD", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ad1bb6274b70a3838e5ee15a3cfd32219", null ],
      [ "DDSP_BUILD_BUSSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a50eee6b1d2ce71b7eb18f960c68d5698", null ],
      [ "DDSP_BUILD_TRUCKSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a8cb5567de12d67fecd679df54769e8d1", null ],
      [ "DDSP_REMOVE_BUSSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a51566cf67283fcbce0fcb8192ad9086c", null ],
      [ "DDSP_REMOVE_TRUCKSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab330fc890bf33eba08605c5501f3b3e5", null ]
    ] ],
    [ "ViewportPlaceMethod", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3", [
      [ "VPM_X_OR_Y", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3ad72518ea9b27a7de4940ad984b278ecf", null ],
      [ "VPM_FIX_X", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3aabec43da0bd072a7a005ecfe89306dbe", null ],
      [ "VPM_FIX_Y", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a082fdffa7dd09cbd6895afeef859ef0a", null ],
      [ "VPM_X_AND_Y", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a87c0b5e04e562b0108c240ba267585be", null ],
      [ "VPM_X_AND_Y_LIMITED", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a6da39a13dec37c738c9e251080c1b747", null ],
      [ "VPM_FIX_HORIZONTAL", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a99d8d7be06cecebd0ae152136763580f", null ],
      [ "VPM_FIX_VERTICAL", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a705c61f9406ecae06c053165532832b5", null ],
      [ "VPM_X_LIMITED", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a867468e0f824486c78c547b379301c91", null ],
      [ "VPM_Y_LIMITED", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a44bdd5443103f342be0e116ef6d3648e", null ],
      [ "VPM_RAILDIRS", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3ae9143ddb3db3422f18059cfea304c31b", null ],
      [ "VPM_SIGNALDIRS", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3ac2fba5538f423641921120435ebfe4f0", null ]
    ] ],
    [ "ViewportScrollTarget", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073a", [
      [ "VST_EVERYONE", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073aa1654650c95c97d962e97b24ef149c2a9", null ],
      [ "VST_COMPANY", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073aa4c47496af397bb821eb64b3860574c96", null ],
      [ "VST_CLIENT", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073aae85dc6425ba2cbcdad8bd809aba2fa5a", null ]
    ] ],
    [ "ViewportSignMargin", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588d", [
      [ "VPSM_LEFT", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588dae04c0d8aba3ab56f992597536846cc00", null ],
      [ "VPSM_RIGHT", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588da27701b562096e155e2d21d0801c9d6e6", null ],
      [ "VPSM_TOP", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588da789d6dab228fa3ba304172c6b5e3ad92", null ],
      [ "VPSM_BOTTOM", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588da89544df4a861a61f2b8788d46ef6a80b", null ]
    ] ],
    [ "ZoomStateChange", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4", [
      [ "ZOOM_IN", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4a7004ff32d6c8d103b61fc07eba87eb85", null ],
      [ "ZOOM_OUT", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4aded0489c394761d74fe468e935d9a6f3", null ],
      [ "ZOOM_NONE", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4a8c633222bc40a7e73809732ac879de5c", null ]
    ] ],
    [ "BB_HEIGHT_UNDER_BRIDGE", "d7/daa/viewport__type_8h.html#a071f9bc7da6d5f4c69dccd9c55443a34", null ],
    [ "BB_Z_SEPARATOR", "d7/daa/viewport__type_8h.html#a6d15a5a5347638aa25cb960a1fbcd7c2", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d7/daa/viewport__type_8h.js <==
var viewport__type_8h =
[
    [ "Viewport", "db/d51/structViewport.html", "db/d51/structViewport" ],
    [ "ViewportSign", "dc/d5e/structViewportSign.html", "dc/d5e/structViewportSign" ],
    [ "TrackedViewportSign", "dc/d1d/structTrackedViewportSign.html", "dc/d1d/structTrackedViewportSign" ],
    [ "ViewportDragDropSelectionProcess", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30", [
      [ "DDSP_DEMOLISH_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a85654f9645b8a2c365a504b61f21f16a", null ],
      [ "DDSP_RAISE_AND_LEVEL_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab6dd9eb95212827a1b570f10807d1026", null ],
      [ "DDSP_LOWER_AND_LEVEL_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a7096ba7607c7470a607660fb0e7bb217", null ],
      [ "DDSP_LEVEL_AREA", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab96b982939642251738df6d3c90a5f9e", null ],
      [ "DDSP_CREATE_DESERT", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a381d6451157c023f4fc9caf91724953f", null ],
      [ "DDSP_CREATE_ROCKS", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab1eb3e76148b1fb677c73bedd4cb3b79", null ],
      [ "DDSP_CREATE_WATER", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ac76d074d64e592506e9dd130b5a85a61", null ],
      [ "DDSP_CREATE_RIVER", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30adabd68f7dd962e9c9ea63a76eb9f8d24", null ],
      [ "DDSP_PLANT_TREES", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30acde8021d08a024a7b35d9067eb86c786", null ],
      [ "DDSP_BUILD_BRIDGE", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30af7a2f4c3b2084bdca11e0f0b44839406", null ],
      [ "DDSP_PLACE_RAIL", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30afdc07064cb21e25f2d8ce1f4101ec4fb", null ],
      [ "DDSP_BUILD_SIGNALS", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a895a704df13e062c23a2836d689257c2", null ],
      [ "DDSP_BUILD_STATION", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30abefc13bb25bea86d7bc45b328443508e", null ],
      [ "DDSP_REMOVE_STATION", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a8f7a7841a90238e9dad2b7570cc3eb3e", null ],
      [ "DDSP_CONVERT_RAIL", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a825f39718462a1f2220ce327bf490569", null ],
      [ "DDSP_PLACE_ROAD_X_DIR", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30aec49bff51948889c36e85dcba8a78597", null ],
      [ "DDSP_PLACE_ROAD_Y_DIR", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a263cf270b24732d2a5c06c32a8dfa824", null ],
      [ "DDSP_PLACE_AUTOROAD", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ad1bb6274b70a3838e5ee15a3cfd32219", null ],
      [ "DDSP_BUILD_BUSSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a50eee6b1d2ce71b7eb18f960c68d5698", null ],
      [ "DDSP_BUILD_TRUCKSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a8cb5567de12d67fecd679df54769e8d1", null ],
      [ "DDSP_REMOVE_BUSSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30a51566cf67283fcbce0fcb8192ad9086c", null ],
      [ "DDSP_REMOVE_TRUCKSTOP", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30ab330fc890bf33eba08605c5501f3b3e5", null ],
      [ "DDSP_CONVERT_ROAD", "d7/daa/viewport__type_8h.html#aa8218ba9183453211f90c83583262a30afef037e1060055ff3c42f6d0e429ebba", null ]
    ] ],
    [ "ViewportPlaceMethod", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3", [
      [ "VPM_X_OR_Y", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3ad72518ea9b27a7de4940ad984b278ecf", null ],
      [ "VPM_FIX_X", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3aabec43da0bd072a7a005ecfe89306dbe", null ],
      [ "VPM_FIX_Y", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a082fdffa7dd09cbd6895afeef859ef0a", null ],
      [ "VPM_X_AND_Y", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a87c0b5e04e562b0108c240ba267585be", null ],
      [ "VPM_X_AND_Y_LIMITED", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a6da39a13dec37c738c9e251080c1b747", null ],
      [ "VPM_FIX_HORIZONTAL", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a99d8d7be06cecebd0ae152136763580f", null ],
      [ "VPM_FIX_VERTICAL", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a705c61f9406ecae06c053165532832b5", null ],
      [ "VPM_X_LIMITED", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a867468e0f824486c78c547b379301c91", null ],
      [ "VPM_Y_LIMITED", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3a44bdd5443103f342be0e116ef6d3648e", null ],
      [ "VPM_RAILDIRS", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3ae9143ddb3db3422f18059cfea304c31b", null ],
      [ "VPM_SIGNALDIRS", "d7/daa/viewport__type_8h.html#aec22a4cd53454b729c7f60a7a1a302d3ac2fba5538f423641921120435ebfe4f0", null ]
    ] ],
    [ "ViewportScrollTarget", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073a", [
      [ "VST_EVERYONE", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073aa1654650c95c97d962e97b24ef149c2a9", null ],
      [ "VST_COMPANY", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073aa4c47496af397bb821eb64b3860574c96", null ],
      [ "VST_CLIENT", "d7/daa/viewport__type_8h.html#a4bc98841cee4cf0e6d94f4f9d534073aae85dc6425ba2cbcdad8bd809aba2fa5a", null ]
    ] ],
    [ "ViewportSignMargin", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588d", [
      [ "VPSM_LEFT", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588dae04c0d8aba3ab56f992597536846cc00", null ],
      [ "VPSM_RIGHT", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588da27701b562096e155e2d21d0801c9d6e6", null ],
      [ "VPSM_TOP", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588da789d6dab228fa3ba304172c6b5e3ad92", null ],
      [ "VPSM_BOTTOM", "d7/daa/viewport__type_8h.html#aa4d106b28fc3a9fc5c4b00e7e685588da89544df4a861a61f2b8788d46ef6a80b", null ]
    ] ],
    [ "ZoomStateChange", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4", [
      [ "ZOOM_IN", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4a7004ff32d6c8d103b61fc07eba87eb85", null ],
      [ "ZOOM_OUT", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4aded0489c394761d74fe468e935d9a6f3", null ],
      [ "ZOOM_NONE", "d7/daa/viewport__type_8h.html#ad152309b0e8f120476d5b8b6cc7365f4a8c633222bc40a7e73809732ac879de5c", null ]
    ] ],
    [ "BB_HEIGHT_UNDER_BRIDGE", "d7/daa/viewport__type_8h.html#a071f9bc7da6d5f4c69dccd9c55443a34", null ],
    [ "BB_Z_SEPARATOR", "d7/daa/viewport__type_8h.html#a6d15a5a5347638aa25cb960a1fbcd7c2", null ]
];
